@@ -3,6 +3,8 @@ package URI::Fast::IRI;
 use strict;
 use warnings;
 
+our $VERSION = '0.37';
+
 our @ISA = qw(URI::Fast);
 
 =head1 NAME
@@ -25,4 +27,6 @@ programming language system itself.
 
 =cut
 
+sub clone { URI::Fast::IRI->new($_[0]) }
+
 1;
